summaryrefslogtreecommitdiff
path: root/sqlbox/mod_form.php
diff options
context:
space:
mode:
authorJan Klemkow <j.klemkow@wemelug.de>2012-10-09 15:28:22 +0200
committerJan Klemkow <j.klemkow@wemelug.de>2012-10-09 15:28:22 +0200
commit5c7511c7c64f62f44244ba1c9f1aac9952c564e1 (patch)
tree9f10a75a48b2d7df333ada2f6d750dddf430bafb /sqlbox/mod_form.php
parent459313e56b0653e4709694a7e86afc11be514097 (diff)
downloadsqltutor-plugin-5c7511c7c64f62f44244ba1c9f1aac9952c564e1.tar.gz
sqltutor-plugin-5c7511c7c64f62f44244ba1c9f1aac9952c564e1.tar.bz2
sqltutor-plugin-5c7511c7c64f62f44244ba1c9f1aac9952c564e1.zip
Rename 'newmodule' into sqlbox in all files.
Diffstat (limited to 'sqlbox/mod_form.php')
-rw-r--r--sqlbox/mod_form.php18
1 files changed, 9 insertions, 9 deletions
diff --git a/sqlbox/mod_form.php b/sqlbox/mod_form.php
index 53fda02..e1dde18 100644
--- a/sqlbox/mod_form.php
+++ b/sqlbox/mod_form.php
@@ -16,13 +16,13 @@
// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
/**
* The main newmodule configuration form
*
* It uses the standard core Moodle formslib. For more info about them, please
* visit: http://docs.moodle.org/en/Development:lib/formslib.php
*
* @package mod
- * @subpackage newmodule
+ * @subpackage sqlbox
* @copyright 2011 Your Name
* @license http://www.gnu.org/copyleft/gpl.html GNU GPL v3 or later
*/
@@ -34,7 +34,7 @@ require_once($CFG->dirroot.'/course/moodleform_mod.php');
/**
* Module instance settings form
*/
-class mod_newmodule_mod_form extends moodleform_mod {
+class mod_sqlbox_mod_form extends moodleform_mod {
/**
* Defines forms elements
@@ -48,7 +48,7 @@ class mod_newmodule_mod_form extends moodleform_mod {
$mform->addElement('header', 'general', get_string('general', 'form'));
// Adding the standard "name" field
- $mform->addElement('text', 'name', get_string('newmodulename', 'newmodule'), array('size'=>'64'));
+ $mform->addElement('text', 'name', get_string('sqlboxname', 'sqlbox'), array('size'=>'64'));
if (!empty($CFG->formatstringstriptags)) {
$mform->setType('name', PARAM_TEXT);
} else {
@@ -56,18 +56,18 @@ class mod_newmodule_mod_form extends moodleform_mod {
}
$mform->addRule('name', null, 'required', null, 'client');
$mform->addRule('name', get_string('maximumchars', '', 255), 'maxlength', 255, 'client');
- $mform->addHelpButton('name', 'newmodulename', 'newmodule');
+ $mform->addHelpButton('name', 'sqlboxname', 'sqlbox');
// Adding the standard "intro" and "introformat" fields
$this->add_intro_editor();
//-------------------------------------------------------------------------------
// Adding the rest of newmodule settings, spreeading all them into this fieldset
// or adding more fieldsets ('header' elements) if needed for better logic
- $mform->addElement('static', 'label1', 'newmodulesetting1', 'Your newmodule fields go here. Replace me!');
+ $mform->addElement('static', 'label1', 'sqlboxsetting1', 'Your sqlbox fields go here. Replace me!');
- $mform->addElement('header', 'newmodulefieldset', get_string('newmodulefieldset', 'newmodule'));
- $mform->addElement('static', 'label2', 'newmodulesetting2', 'Your newmodule fields go here. Replace me!');
+ $mform->addElement('header', 'sqlboxfieldset', get_string('sqlboxfieldset', 'sqlbox'));
+ $mform->addElement('static', 'label2', 'sqlboxsetting2', 'Your sqlbox fields go here. Replace me!');
//-------------------------------------------------------------------------------
// add standard elements, common to all modules
@@ -16,13 +16,13 @@
// along with Moodle. If not, see <http://www.gnu.org/licenses/>.
/**
- * The main newmodule configuration form
+ * The main sqlbox configuration form
*
* It uses the standard core Moodle formslib. For more info about them, please
@@ -56,18 +56,18 @@ class mod_newmodule_mod_form extends moodleform_mod {
$this->add_intro_editor();
//-------------------------------------------------------------------------------
- // Adding the rest of newmodule settings, spreeading all them into this fieldset
+ // Adding the rest of sqlbox settings, spreeading all them into this fieldset
// or adding more fieldsets ('header' elements) if needed for better logic